from setuptools import setup

setup(name="dwncode",
      version="0.0.1",
      description="Dwn Code",
      long_description="For TE Students",
      author="JOD",
      packages=['dwncode'],
      install_requires=[])
